<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://AmorStyle
 * @since      1.0.0
 *
 * @package    tweb2price
 * @subpackage tweb2price/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    tweb2price
 * @subpackage tweb2price/public
 * @author     AmorStyle <AmorStyleYoga@Hotmail.com>
 */
class tweb2price_shortcode 
{
	// Holds the shortcode options
	private $Localatts = array();

	// holds the last response from the server as a json data string
	private $response_json;
	// holds the last time the server was queried
	private $lasttime; 

	// holds the last response from the server as an array
	private $response_api = array();

	// boolean - ether true of false. false by default.
	private $debug_spew;

	// The URL for getting the price
	private $apiUrl = array();

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct(  )  // $plugin_name, $version
	{
		$this->debug_spew = false;
		$this->response_json = NULL;
		$this->lasttime = 0;

		// two locations provide the content that we want. we'll put both in an array
		// so if one goes down, we can get a response from the other.
		$this->apiUrl[1] = 'http://www.thetascan.io/api/price/';
		$this->apiUrl[2] = 'http://sg.thetascan.io/api/price/';
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tweb2price_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tweb2price_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/tweb2price-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tweb2price_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tweb2price_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/tweb2price-public.js', array( 'jquery' ), $this->version, false );

	}


	// This routine reads the shortcode and sets member variables 
	private function parse_options($atts)
	{
		// Setup the default here
		$defaults = array(	'item' => 'theta_price', // 'theta' or 'tfuel' or 'tdrop'
							'decimals' => '4');		 // how many decimals to display
							
		$this->Localatts = shortcode_atts( $defaults, $atts, 'price' );
	}
	private function DEBUG()
	{
		// output what's true or set
		echo "item: ".$this->Localatts['item']."<br/>";
		echo "decimals: ".$this->Localatts['decimals']."<br/>";
	}

	//
	// Only perform the remote call if we have exceeded the 10 minute threshold. 
	// If not, restore from the database.
	//
	private function remote_call($index)
	{
		$bReturn = false;
		// get the last record.
		$tweb2price_record = new tweb2price_record();

		// Last cached time
		//var_dump("last cached time: ".$tweb2price_record->lasttime()."<br>");

		$curtime = time();
		if( $curtime-$tweb2price_record->lasttime() > 10 ) // that's seconds (ten minutes)
		{
			// It's been a while, make the remote call and update the database
			$response = wp_remote_get($this->apiUrl[$index]);

			if( !is_wp_error( $response ) )
			{
				if( is_array( $response ) )
				{
					// Save this json information so it can be written to the database.
					$this->response_json = wp_remote_retrieve_body( $response );
					$this->response_api = json_decode( wp_remote_retrieve_body( $response ), true );

					// Now update database
					$tweb2price_record = new tweb2price_record();
					$tweb2price_record->update( 1,						// id - should only be one record
												$curtime,				// timestamp
												$this->response_json); // json data
					$bReturn = true;
				}
			}
		}
		else
		{
			//var_dump("delta small: ".($curtime-$tweb2price_record->lasttime())." getting cache<br>");

			// restore from the database
			$this->response_json = $tweb2price_record->json();
			$this->response_api = json_decode( $this->response_json, true );
			$bReturn = true;
		}

		// dump the response array
		//var_dump($this->response_api);
		//var_dump("<br><br><br>");

		return $bReturn;
	}


	public function price()
	{
		$output .= "";

		$bResults = true;
		//$output .= "<br>Perform the call<br>";
		if( !self::remote_call(1) )
		{
			if( !self::remote_call(2) )
			{
				// could not get proper results from either server.
				$bResults = false;
			}
		}
		if( !$bResults )
		{
			$output .= "Offline";
			return $output;
		}

		$item = $this->Localatts['item'];
		$decimals = $this->Localatts['decimals'];
		$price = $this->response_api[$item];

		// Now trim the number down to the number of decimals that the caller wants.

		if( $price != NULL )
		{
			// first, move over the units
			$value = NULL;
			$bcounting = false;
			$points = 0;
			for($i=0;$i<32;$i++)
			{
				// Only move something if we have it.
				if( $price[$i]!= NULL )
				{
					if($price[$i] != '.')
					{
						$value[$i] = $price[$i];
						//echo $price[$i]." -> ".$value[$i]."<br>";
						$points ++;
					}

					if($price[$i] == '.')
					{
						// if they ask for zero decimal places
						if( $decimals == 0 )
						{
							break; // we're done
						}
						$value[$i] = $price[$i];
						//echo $price[$i]." -> ".$value[$i]."<br>";
						$bcounting = true;
						$points = 0;
					}

					if( $bcounting )
					{
						if( $points >= $decimals )
						{
							break;
						}
					}
				}
			}
			if( $value != NULL )
			{
				$value_str = implode($value);
				//$output .= $item.": ".$price.", trimmed to: ".$value_str."<br>";
				$output .= $value_str;
			}
		}
		else
		{
			// The item was not parsed out of the response. It's as if the response has
			// changed or the source for info went down.
			$output .= "Undefined";
		}

		return $output;
	}

	public function main($atts)
	{
		// All information needs to be returned in a string.
		$output = ""; //"START SHORTCODE<br>";

		self::parse_options($atts, $output);
		//self::DEBUG();

		$output .= self::price();

		return $output; //."<br>END SHORTCODE<br>";	}
	}
}

//
// Main shortcode entrypoint. 
//
function tweb2price_shortcode( $atts )
{
	// ob_start() and ob_get_clean() are used so echo can be used in development
	ob_start();
	$Shortcode=new tweb2price_shortcode();
	$Text=$Shortcode->main($atts);

	// Need to determine what platform we're on
	$Location = site_url();
	if( stristr($Location,"localhost") != false )
	{
		// Debug spew here..
		return ob_get_clean().$Text;
	}
	else
	{
		// No Debug Spew.
		ob_get_clean();
		return $Text;
	}
}
